package com.zhili.stationserver.component.stationserver;

import com.zhili.stationserver.component.stationserver.handler.StationMessageDecoder;
import com.zhili.stationserver.component.stationserver.handler.StationMessageEncoder;
import com.zhili.stationserver.component.stationserver.handler.StationMessageHandler;
import io.netty.bootstrap.ServerBootstrap;
import io.netty.channel.*;
import io.netty.channel.nio.NioEventLoopGroup;
import io.netty.channel.socket.SocketChannel;
import io.netty.channel.socket.nio.NioServerSocketChannel;
import io.netty.handler.timeout.IdleStateHandler;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.util.concurrent.TimeUnit;

/**
 * @author ：HuangBin
 * @description：TODO
 * @date ：2023/4/17 14:21
 */
@Component
@Slf4j
public class StationServer {
    EventLoopGroup bossGroup;
    EventLoopGroup workerGroup;
    ServerBootstrap sbs;

    @Value("${station-server.port}")
    int port;

    public StationServer() {
        bossGroup = new NioEventLoopGroup(1);
        workerGroup = new NioEventLoopGroup();
        sbs = new ServerBootstrap();
        sbs.group(bossGroup, workerGroup)
                .channel(NioServerSocketChannel.class)
                .childOption(ChannelOption.SO_KEEPALIVE, true)
                .childOption(ChannelOption.TCP_NODELAY, true)
                .option(ChannelOption.SO_BACKLOG, 1024)
                .childHandler(new ChannelInitializer<SocketChannel>() {
                    @Override
                    protected void initChannel(SocketChannel socketChannel) throws Exception {
                        socketChannel.pipeline()
                                //心跳10s上报一次
                                .addLast(new IdleStateHandler(25, 0, 0, TimeUnit.SECONDS))
                                .addLast(new StationMessageDecoder())
                                .addLast(new StationMessageEncoder())
                                .addLast(new StationMessageHandler());
                    }
                });
    }

    @PostConstruct
    public void run() {
        ChannelFuture channelFuture = sbs.bind(port);
        //服务器停后，3s再次尝试启动。
        channelFuture.channel().closeFuture().addListener(new ChannelFutureListener() {
            @Override
            public void operationComplete(ChannelFuture future) throws Exception {
                log.error("station server closed");
                if (future.isSuccess()) {
                    future.channel().eventLoop().schedule(() -> {
                        run();
                    }, 3, TimeUnit.SECONDS);
                }
            }
        });
    }
}
