package com.zhili.stationserver.dto;

import com.zhili.stationserver.util.BytesUtil;
import lombok.Data;
import org.apache.commons.lang3.ArrayUtils;

/**
 * @author ：jek
 * @title 换电记录
 * @date ：2023/2/8 17:34
 */
@Data
public class ExchangeRecordInfo {
    /** 换电编号 */
    String exchangeNo;
    /**	流水号*/
    String serialNo;
    /**	车牌号*/
    String plate;
    /**	vin */
    String vin;
    /**	车型*/
    String model;
    /**	站点编号*/
    String stationCode;
    /**	司机名字*/
    String driverName;
    /**	司机id*/
    Integer driverId;
    /** 司机电话  */
    String driverPhone;
    /**  亏电电池sn */
    String sourceBatterySn;
    /**  满电电池sn */
    String targetBatterySn;
    /**  亏电电池容量 */
    Double sourceCapacity;
    /** 满电电池容量  */
    Double targetCapacity;
    /**  亏电电池soc */
    Double sourceSoc;
    /** 满电电池soc  */
    Double targetSoc;
    /** 亏电电池soh  */
    Double sourceSoh;
    /**  满电电池soh */
    Double targetSoh;
    /**  换电量 */
    Double exchangePower;
    /**  换电费 */
    Double powerFee;
    /** 服务费  */
    Double serviceFee;
    /**  开始时间 */
    String startTime;
    /**  结束时间 */
    String endTime;
    /**  发起换电来源 0：站控，1：小程序*/
    Integer startSource;
    /**  车辆总里程 */
    Double totalMileage;
    /**  车辆id */
    private Integer vehicleId;


    public ExchangeRecordInfo(String stationCode, byte[] data) {
        this.stationCode = stationCode;
        exchangeNo = BytesUtil.parseString(ArrayUtils.subarray(data, 0, 32));
        serialNo = BytesUtil.parseString(ArrayUtils.subarray(data, 32, 64));
        plate = BytesUtil.deUnicode(ArrayUtils.subarray(data, 64, 84));
        vin = BytesUtil.parseString(ArrayUtils.subarray(data, 84, 101));
        model = BytesUtil.deUnicode(ArrayUtils.subarray(data, 101, 117));
        driverName = BytesUtil.deUnicode(ArrayUtils.subarray(data, 149, 181));
        driverPhone = BytesUtil.parseString(ArrayUtils.subarray(data, 181, 192));
        sourceBatterySn = BytesUtil.parseString(ArrayUtils.subarray(data, 192, 219));
        targetBatterySn = BytesUtil.parseString(ArrayUtils.subarray(data, 219, 246));
        sourceCapacity = BytesUtil.toIntWithLowerFirst(ArrayUtils.subarray(data, 246, 250)) * 0.2d / 100;
        targetCapacity = BytesUtil.toIntWithLowerFirst(ArrayUtils.subarray(data, 250, 254)) * 0.2d / 100;
        sourceSoc = BytesUtil.toIntWithLowerFirst(ArrayUtils.subarray(data, 254, 258)) * 0.2d / 100;
        targetSoc = BytesUtil.toIntWithLowerFirst(ArrayUtils.subarray(data, 258, 262)) * 0.2d / 100;
        sourceSoh = BytesUtil.toIntWithLowerFirst(ArrayUtils.subarray(data, 262, 266)) * 0.2d / 100;
        targetSoh = BytesUtil.toIntWithLowerFirst(ArrayUtils.subarray(data, 266, 270)) * 0.2d / 100;
        exchangePower = BytesUtil.toIntWithLowerFirst(ArrayUtils.subarray(data, 270, 274)) * 0.2d / 100;
        powerFee = BytesUtil.toIntWithLowerFirst(ArrayUtils.subarray(data, 274, 278)) * 0.2d / 100;
        serviceFee = BytesUtil.toIntWithLowerFirst(ArrayUtils.subarray(data, 278, 282)) * 0.2d / 100;
        startTime = BytesUtil.composeTimeString(ArrayUtils.subarray(data, 282, 290));
        endTime = BytesUtil.composeTimeString(ArrayUtils.subarray(data, 290, 298));
        startSource =  Byte.toUnsignedInt(data[298]);
        driverId = BytesUtil.toIntWithLowerFirst(ArrayUtils.subarray(data, 299, 303));
        totalMileage = BytesUtil.toIntWithLowerFirst(ArrayUtils.subarray(data, 303, 311)) * 0.2d / 100;
        vehicleId = BytesUtil.toIntWithLowerFirst(ArrayUtils.subarray(data, 311, 315));
    }

}
