package com.zhili.stationserver.dto;

import com.zhili.stationserver.annotation.ProtocalTranform;
import com.zhili.stationserver.annotation.TransformField;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;

import static com.zhili.stationserver.constant.TransformType.*;

/**
 * 上传换电记录对象
 */
@Data
@ProtocalTranform(command = StationMessage.CommandType.EXCHANGE_RECORD, size = 319)
@NoArgsConstructor
public class SwapRecordDTO implements Serializable {

    //("换电编号")
    @TransformField(start = 0, type = STRING_TYPE, length = 32)
    private String exchangeNo;

    //("车牌号")
    @TransformField(start = 32, type = STRING_TYPE, length = 10)
    private String plate;

    //("车辆识别码")
    @TransformField(start =42, type = STRING_TYPE, length = 17)
    private String vin;

    //("车型")
    @TransformField(start = 59, type = STRING_TYPE, length = 16)
    private String model;

    //("站点编号")
    @TransformField(start = 75, type = STRING_TYPE, length = 11)
    private String stationCode;

    //("司机id")
    @TransformField(start = 86, type = UINT_TYPE, length = 4)
    private Integer driverId;

    //("司机姓名")
    @TransformField(start = 97, type = STRING_TYPE, length = 32)
    private String driverName;

    //("司机手机号")
    @TransformField(start = 129, type = STRING_TYPE, length = 11)
    private String driverPhone;

    //("亏电电池sn")
    @TransformField(start = 140, type = STRING_TYPE, length = 27)
    private String sourceBatterySn;

    //("满电电池sn")
    @TransformField(start = 167, type = STRING_TYPE, length = 27)
    private String targetBatterySn;

    //("亏电电池容量")
    @TransformField(start = 194, type = FLOAT_TYPE, accuracy = 0.1f, length = 8)
    private Float sourceCapacity;

    //("满电电池容量")
    @TransformField(start = 202, type = FLOAT_TYPE, accuracy = 0.1f, length = 8)
    private Float targetCapacity;

    //("亏电电池soc")
    @TransformField(start = 210, type = FLOAT_TYPE, accuracy = 0.1f, length = 4)
    private Float sourceSoc;

    //("满电电池soc")
    @TransformField(start = 214, type = FLOAT_TYPE, accuracy = 0.1f, length = 4)
    private Float targetSoc;

    //("亏电电池soh")
    @TransformField(start = 218, type = FLOAT_TYPE, accuracy = 0.1f, length = 4)
    private Float sourceSoh;

    //("满电电池soh")
    @TransformField(start = 222, type = FLOAT_TYPE, accuracy = 0.1f, length = 4)
    private Float targetSoh;

    //("满电电池仓位")
    @TransformField(start = 226, type = UINT_TYPE)
    private Integer targetCode;

    //("预选电池仓位")
    @TransformField(start = 227, type = UINT_TYPE)
    private Integer preselectionCode;

    //("预选电池编号sn")
    @TransformField(start = 228, type = STRING_TYPE, length = 27)
    private String preselectionSn;

    //("预选电池SOC")
    @TransformField(start = 255, type = FLOAT_TYPE, accuracy = 0.1f, length = 4)
    private Float preselectionSoc;

    //("预选电池SOH")
    @TransformField(start = 259, type = FLOAT_TYPE, accuracy = 0.1f, length = 4)
    private Float preselectionSoh;

    //("发起换电开始时间")
    @TransformField(start = 263, type = TIME_STRING_TYPE, length = 8)
    private String startTime;

    //("换电结束时间")
    @TransformField(start = 271, type = TIME_STRING_TYPE, length = 8)
    private String endTime;

    //("换电plc启动时间")
    @TransformField(start = 279, type = TIME_STRING_TYPE, length = 8)
    private String swapStartTime;

    //("调仓开始时间")
    @TransformField(start = 287, type = TIME_STRING_TYPE, length = 8)
    private String exchangeTime;

    //("启动来源 0：站控，1：小程序")
    @TransformField(start = 295, type = UINT_TYPE)
    private Integer startSource;

    //("是否急停过0,没有，1发生")
    @TransformField(start = 296, type = UINT_TYPE)
    private Integer everEmergency;

    //("是否中止过0,没有，1发生")
    @TransformField(start = 297, type = UINT_TYPE)
    private Integer everStop;

    //("是否暂停过0,没有，1发生")
    @TransformField(start = 298, type = UINT_TYPE)
    private Integer everPause;

    //("是否故障过0,没有，1发生")
    @TransformField(start = 299, type = UINT_TYPE)
    private Integer everFault;

    //("是否手动过0,没有，1发生")
    @TransformField(start = 300, type = UINT_TYPE)
    private Integer everManually;

    //("电池选择模式:0:自动，1手动")
    @TransformField(start = 301, type = UINT_TYPE)
    private Integer chooseMode;

    //("车辆总里程KM")
    @TransformField(start = 302, type = FLOAT_TYPE, accuracy = 0.1f, length = 8)
    private Float totalMileage;

    //("换电状态 0不完整 1换电成功 2换电失败 3换电错误")
    @TransformField(start = 310, type = UINT_TYPE)
    private Integer swapState;

    //("上传时间")
    @TransformField(start = 311, type = TIME_STRING_TYPE, length = 8)
    private String uploadTime;

    //service服务id 用来接收记录保存状态回传
    private String serviceInstanceId;

    //用来接收记录保存状态回传站控
    private String connIdStr;
}
